Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/collada/collada_utils.h')
-rw-r--r--source/blender/collada/collada_utils.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/collada/collada_utils.h b/source/blender/collada/collada_utils.h
index fc171d8d3b9..1e18ac56e5d 100644
--- a/source/blender/collada/collada_utils.h
+++ b/source/blender/collada/collada_utils.h
@@ -90,13 +90,13 @@ inline bAction *bc_getSceneObjectAction(Object *ob)
return (ob->adt && ob->adt->action) ? ob->adt->action : NULL;
}
/* Returns Lamp Action or NULL */
inline bAction *bc_getSceneLampAction(Object *ob)
{
if (ob->type != OB_LAMP)
return NULL;
- Lamp *lamp = (Lamp *)ob->data;
+ Light *lamp = (Light *)ob->data;
return (lamp->adt && lamp->adt->action) ? lamp->adt->action : NULL;
}
@@ -90,13 +90,13 @@ inline bAction *bc_getSceneObjectAction(Object *ob)
return (ob->adt && ob->adt->action) ? ob->adt->action : NULL;
}
-/* Returns Lamp Action or NULL */
+/* Returns Light Action or NULL */
inline bAction *bc_getSceneLampAction(Object *ob)
{